==> kubernetes-model-1.0.56-sources.jar: annotations/io/fabric8/kubernetes/api/model/IntOrStringBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class IntOrStringBuilder extends IntOrStringFluentImpl<IntOrStringBuilder> implements VisitableBuilder<IntOrString,IntOrStringBuilder>{

    IntOrStringFluent<?> fluent;
    Boolean validationEnabled;

    public IntOrStringBuilder(){
            this(true);
    }
    public IntOrStringBuilder(Boolean validationEnabled){
            this(new IntOrString(), validationEnabled);
    }
    public IntOrStringBuilder(IntOrStringFluent<?> fluent){
            this(fluent, true);
    }
    public IntOrStringBuilder(IntOrStringFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new IntOrString(), validationEnabled);
    }
    public IntOrStringBuilder(IntOrStringFluent<?> fluent,IntOrString instance){
            this(fluent, instance, true);
    }
    public IntOrStringBuilder(IntOrStringFluent<?> fluent,IntOrString instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withIntVal(instance.getIntVal()); 
            fluent.withKind(instance.getKind()); 
            fluent.withStrVal(instance.getStrVal()); 
            fluent.withAdditionalProperties(instance.getAdditionalProperties()); 
            fluent.withIntVal(instance.getIntVal());

            fluent.withKind(instance.getKind());

            fluent.withStrVal(instance.getStrVal());

            this.validationEnabled = validationEnabled; 
    }
    public IntOrStringBuilder(IntOrString instance){
            this(instance,true);
    }
    public IntOrStringBuilder(IntOrString instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withIntVal(instance.getIntVal()); 
            this.withKind(instance.getKind()); 
            this.withStrVal(instance.getStrVal()); 
            this.withAdditionalProperties(instance.getAdditionalProperties()); 
            this.withIntVal(instance.getIntVal());

            this.withKind(instance.getKind());

            this.withStrVal(instance.getStrVal());

            this.validationEnabled = validationEnabled; 
    }

    public IntOrString build(){
            IntOrString buildable = new IntOrString(fluent.getIntVal(),fluent.getKind(),fluent.getStrVal(),fluent.getAdditionalProperties());
            buildable.setIntVal(fluent.getIntVal());
            buildable.setKind(fluent.getKind());
            buildable.setStrVal(fluent.getStrVal());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            IntOrStringBuilder that = (IntOrStringBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/kubernetes/api/model/IntOrStringBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class IntOrStringBuilder extends IntOrStringFluentImpl<IntOrStringBuilder> implements VisitableBuilder<IntOrString,IntOrStringBuilder>{

    IntOrStringFluent<?> fluent;
    Boolean validationEnabled;

    public IntOrStringBuilder(){
            this(true);
    }
    public IntOrStringBuilder(Boolean validationEnabled){
            this(new IntOrString(), validationEnabled);
    }
    public IntOrStringBuilder(IntOrStringFluent<?> fluent){
            this(fluent, true);
    }
    public IntOrStringBuilder(IntOrStringFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new IntOrString(), validationEnabled);
    }
    public IntOrStringBuilder(IntOrStringFluent<?> fluent,IntOrString instance){
            this(fluent, instance, true);
    }
    public IntOrStringBuilder(IntOrStringFluent<?> fluent,IntOrString instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withIntVal(instance.getIntVal()); 
            fluent.withKind(instance.getKind()); 
            fluent.withStrVal(instance.getStrVal()); 
            fluent.withAdditionalProperties(instance.getAdditionalProperties()); 
            fluent.withIntVal(instance.getIntVal());

            fluent.withKind(instance.getKind());

            fluent.withStrVal(instance.getStrVal());

            this.validationEnabled = validationEnabled; 
    }
    public IntOrStringBuilder(IntOrString instance){
            this(instance,true);
    }
    public IntOrStringBuilder(IntOrString instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withIntVal(instance.getIntVal()); 
            this.withKind(instance.getKind()); 
            this.withStrVal(instance.getStrVal()); 
            this.withAdditionalProperties(instance.getAdditionalProperties()); 
            this.withIntVal(instance.getIntVal());

            this.withKind(instance.getKind());

            this.withStrVal(instance.getStrVal());

            this.validationEnabled = validationEnabled; 
    }

    public IntOrString build(){
            IntOrString buildable = new IntOrString(fluent.getIntVal(),fluent.getKind(),fluent.getStrVal(),fluent.getAdditionalProperties());
            buildable.setIntVal(fluent.getIntVal());
            buildable.setKind(fluent.getKind());
            buildable.setStrVal(fluent.getStrVal());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            IntOrStringBuilder that = (IntOrStringBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
